pub fn update_user(body: &User) -> Request<EmptyResponse>Expand description
Note that UserPublicId must be set when updating a user. It is used to identify which user to update.
pub fn update_user(body: &User) -> Request<EmptyResponse>Note that UserPublicId must be set when updating a user. It is used to identify which user to update.